FUNCTION extract,image,center,width,woff,width_sky,pswitch=pswitch,fswitch=fswitch,degree=degree,nosky=nosky

; image      input image
; center     central line of spectrum
; width      width of spectrum
; woff       separation spectrum sky background
; width_sky  width of sky background
; pswitch    plot switch: 0 no plots, 1 poly fit and reduction, 2 gauss fit also
; fswitch    fit gauss for central line of spectrum
; degree     dergee of polynom fit for central line of spectrum
; nosky      prevent sky subtraction in case of calibration spectra

siz = size(pswitch)
IF siz(1) EQ 0 THEN pswitch = 1
siz = size(fswitch)
IF siz(1) EQ 0 THEN fswitch = 1
siz = size(degree)
IF siz(1)  EQ 0 THEN degree  = 3


on_error,2

s = size(image)

x = fltarr(2*width+1)
y = fltarr(2*width+1)
cen  = fltarr(s(1))
flux = fltarr(s(1))
sky  = fltarr(s(1))
xaxis= findgen(s(1))
edge = fltarr(s(1),6)
ima  = fltarr(s(1),width+1 + 2*width_sky+2 +2)
sky1 = fltarr(width_sky+1)
sky2 = fltarr(width_sky+1)

loadct,39

IF (fswitch EQ 1) THEN BEGIN
   FOR ii=0,s(1)-1 DO BEGIN
       flux(ii) = 0.
       FOR j=0,2*width DO BEGIN
           x(j) = center - width + j
           y(j) = image(ii,x(j))
       ENDFOR 
       yfit = gaussfit(x,y,a,nterms=4)
       cen(ii) = a(1)
       IF (pswitch EQ 2) THEN BEGIN
          wset,2
          plot,rebin(x*1.,99*(2*width+1)),a(3)+a(0)*exp(-((rebin(x*1.,99*(2*width+1))-a(1))/a(2))^2/2.),xtitle='pixel position'
          oplot,x,y,color=150
          wait,0.1
       ENDIF
   ENDFOR
   IF (pswitch GT 0) THEN BEGIN
       wset,3
       plot,xaxis,cen,xtitle='pixel position direction dispersion',ytitle='pixel position ',ystyle=1
   ENDIF
   fitcoeff = poly_fit(xaxis,cen,degree,/double)
   cen = fitcoeff(0)
   FOR k = 1,degree DO cen = cen + fitcoeff(k)*xaxis^k
   IF (pswitch GT 0) THEN BEGIN
       oplot,xaxis,cen,color=150
   ENDIF
ENDIF ELSE BEGIN
   cen(*) = center 
ENDELSE
    
FOR ii=0,s(1)-1 DO BEGIN
    flux(ii) = total(image(ii,fix(cen(ii)+0.5)-width/2:fix(cen(ii)+0.5)+width/2))

    sky1 = image(ii,fix(cen(ii)+0.5)-woff-width_sky:fix(cen(ii)+0.5)-woff)
    sky2 = image(ii,fix(cen(ii)+0.5)+woff:fix(cen(ii)+0.5)+woff+width_sky)
    sky(ii) = float(width+1)*(median(sky1)+median(sky2))/2.

    IF NOT keyword_set(nosky) THEN flux(ii) = flux(ii) - sky(ii)

    edge(ii,0) =  fix(cen(ii)+0.5) - width/2
    edge(ii,1) =  fix(cen(ii)+0.5) + width/2
    edge(ii,2) =  fix(cen(ii)+0.5) -woff - width_sky
    edge(ii,3) =  fix(cen(ii)+0.5) -woff
    edge(ii,4) =  fix(cen(ii)+0.5) +woff 
    edge(ii,5) =  fix(cen(ii)+0.5) +woff + width_sky

    ima(ii,0:width_sky)                   =       image(ii,fix(edge(ii,2)):fix(edge(ii,3)))
    ima(ii,width_sky+1) = -100.
    ima(ii,width_sky+2:width_sky+width+2) =       image(ii,fix(edge(ii,0)):fix(edge(ii,1)))
    ima(ii,width_sky+width+3) = -100.
    ima(ii,width_sky+width+4:2*width_sky+width+4)=image(ii,fix(edge(ii,4)):fix(edge(ii,5)))
 
    center = cen(ii)
ENDFOR

;IF (pswitch GT 0) THEN ccd_tv,ima


IF (pswitch GT 0) THEN BEGIN
    wset,1
    shade_surf,ima,xtitle='direction dispersion'
ENDIF

print,'% EXTRACT: Extraction done' 
IF (pswitch GT 0) THEN wset,0

return,flux
END 
