function SPEX_FIT_WAVE,image,degree,width=width,ylow=ylow,yhigh=yhigh, $
                  autofind=autofind,spectrum=spectrum,file=file,       $
                  start=start,writeFlag=writeFlag


; image      input image
; degree     degree of polynomial fit 
; width      line width for gauss centering
; ylow       low cut for yrange
; yhigh      high cut for yrange
;
;; ---------------------------------------------------------
;; --- DEFAULTS & DECLARATIONS
;;

loadct,39

dim_ima = size(image)
cdummy  = ''

siz = size(width)
IF siz(1) EQ 0 THEN    width = 14 ELSE width = fix(width)
siz = size(ylow)
IF siz(1) EQ 0 THEN     ylow = 0
siz = size(yhigh)
IF siz(1) EQ 0 THEN    yhigh = max(image)
siz = size(autofind)
IF siz(1) EQ 0 THEN autofind = 1
siz = size(spectrum)
IF siz(1) EQ 0 THEN spectrum = 'HeAr.dat'
siz = size(file)
IF siz(1) EQ 0 THEN    file  = 'wave_fit.dat'
siz = size(start)
IF siz(1) EQ 0 THEN    start = 1
siz = size(writeFlag)
IF siz(1) EQ 0 THEN    writeFlag  = 0


restart:

xf = fltarr(1000)
yf = fltarr(1000)
xaxis = fltarr(width+1)
counter = 0l

plot,image,yrange=[ylow,yhigh],ystyle=1,xtitle='pixel'


IF start EQ 1 THEN BEGIN
;; ---------------------------------------------------------
;; --- GIVE FIRST WAVELENGTHS INTERACTIVELY
;;
    ;; --- read in values
    message,'Left   mouse click   : Mark points',/inf
    message,'Middle mouse click   : end ',/inf

    REPEAT BEGIN
        next_try:
        PRINT,counter
        cursor,xx,yy,/data
        mouse=!mouse.button
        IF (mouse eq 2) THEN GOTO,stop
        FOR k=0,width DO xaxis(k) = xx-width/2+k
        gfit =  gaussfit(xaxis,image[xx-width/2:xx+width/2],a,nterms=4)
        xf[counter] = a(1)
        oplot,xaxis,a(3)+a(0)*exp(-((xaxis-a(1))/a(2))^2/2.),color=120
        message,'enter wavelength:',/inf
        message,'or type c to skip:',/inf
        read,cdummy                         ;; wait for orders
        CASE cdummy OF
            'c': BEGIN 
                message,'skipping identification... ',/inf
                GOTO,next_try 
            END 
            ELSE: BEGIN 
                yy = float(cdummy)
                yf[counter] = yy
                mouse=!mouse.button
                wait,0.1
                counter = counter + 1
            END 
        ENDCASE 
    stop:
    ENDREP UNTIL (mouse eq 2)

    newfit1:
    index1 = where (xf NE 0.)
    index2 = sort(xf[index1])
    
    ;; --- try polynomial fit
    IF degree GT counter -1 THEN BEGIN 
        PRINT,'% SPEX_FIT_WAVE: not enough points to fit polynomial of degree '$
          +strtrim(string(degree),2)
        PRINT,'% SPEX_FIT_WAVE: resting to '+strtrim(string(counter-1),2)
        wavcoeff = poly_fit(xf[index2],yf[index2],counter-1,/double)
    ENDIF ELSE BEGIN 
        counter = degree + 1
        wavcoeff = poly_fit(xf[index2],yf[index2],counter-1,/double)
    ENDELSE 
    
    xx = findgen(dim_ima[1])
    yy = findgen(dim_ima[1])
    yy[*] = wavcoeff[0]
    FOR k = 1,counter-1 DO yy = yy + wavcoeff[k]*xx^k
;    windowset,1
    plot, xf, yf, psym=5, yrange = [min(yy),max(yy)], ystyle = 1, $
      xtitle='pixel',ytitle='wavelength'
    oplot,xx,yy,color=20
    PRINT,'% SPEX_FIT_WAVE: ready to continue? press return'
    read,cdummy                                     ;; wait for orders
;    windowset,2
    yfit = dblarr(counter)
    FOR k = 0,counter-1 DO yfit = yfit + wavcoeff[k]*xf(0:counter)^k    

    plot,xf(0:counter),yf(0:counter)-yfit,psym=5,ystyle=1,   $
         xtitle='pixel',ytitle='residual '+string("305B),color=20
    plot,xf(0:counter),yf(0:counter)-yfit,psym=5,ystyle=1,   $
         xtitle='pixel',ytitle='residual '+string("305B),/nodata
    oplot,xf(0:counter),yf(0:counter)-yfit,color=20

    PRINT,'% SPEX_FIT_WAVE: accepted fit ?       press return'
    PRINT,'% SPEX_FIT_WAVE: new polynomial fit ? enter degree'
    read,cdummy
    IF cdummy NE '' THEN BEGIN 
        degree = fix(cdummy)
        GOTO,newfit1
    ENDIF 

ENDIF ELSE BEGIN 
;; ---------------------------------------------------------
;; --- ALTERNATIVELY, READ WAVE COEFFICIENTS FROM FILE
;;
    openr,unit,file,/get_lun
    readf,unit,counter
    wavcoeff = dblarr(counter+1)
    readf,unit,wavcoeff
    free_lun,unit
    xf(0:counter) = 10 + findgen(counter+1)*dim_ima(1)/(counter+1)
    yf(0:counter) = wavcoeff[0]
    FOR k = 1,counter DO yf(0:counter)=yf(0:counter)+wavcoeff[k]*xf(0:counter)^k
    xx = findgen(dim_ima[1])
    yy = findgen(dim_ima[1])
    yy[*] = wavcoeff[0]
    FOR k = 1,counter DO yy = yy + wavcoeff[k]*xx^k
;    windowset,1
    plot, xf, yf, psym=5, yrange = [min(yy),max(yy)], ystyle = 1, $
      xtitle='pixel',ytitle='wavelength'
    oplot,xx,yy,color=20
    PRINT,'% SPEX_FIT_WAVE: ready to continue? press return'
    read,cdummy                 ; wait for orders
;    windowset,2
;    plot,xf,yf-yy
;    PRINT,'% SPEX_FIT_WAVE :  ready to continue? press return'
;    read,cdummy                 ; wait for orders
;    counter = counter+1
ENDELSE 

;; ---------------------------------------------------------
;; --- IDENTIFY THE OTHER LINES AUTOMATICALLY
;;
IF autofind EQ 1 THEN BEGIN
;    windowset,0
    
    plot,image,yrange=[ylow,yhigh],ystyle=1
    
    read_calib:
    openr,unit,spectrum,/get_lun,error=err
    IF err NE 0 THEN BEGIN 
        PRINT,'% SPEX_FIT_WAVE : file not found: ',spectrum
        PRINT,'% SPEX_FIT_WAVE : enter new file for wavelength calibration'
        read,spectrum
        GOTO,read_calib
    ENDIF 
    readf,unit,dim
    spec = dblarr(dim)
    readf,unit,spec
    free_lun,unit

    index1 = where (xf NE 0.)
;    index2 = yf[index1]
    pixcoeff = poly_fit(yf[index1],xf[index1],counter-1,/double)

    countern = 0
    FOR i=0,dim-1 DO BEGIN
        center = 0.
        FOR k = 0,counter-1 DO center = center + pixcoeff(k)*spec(i)^k
        IF center GT dim_ima(1)-width/2 OR center LT width/2 THEN GOTO, weiter
        FOR k=0,width DO xaxis(k) = center-width/2+k
        gfit =  gaussfit(xaxis,image[center-width/2:center+width/2],a,nterms=4)
        xf[countern] = a(1)
        oplot,xaxis,a(3)+a(0)*exp(-((xaxis-a(1))/a(2))^2/2.),color=120
        xyouts,xf[countern],a(0),strtrim(string(spec(i)),2),orientation=90
        yf[countern] = spec(i)
        wait,0.1
        countern = countern + 1
    weiter:
    ENDFOR

    PRINT,'% SPEX_FIT_WAVE: ready to continue? press return'
    PRINT,'% SPEX_FIT_WAVE: type  "re-start" for a new try'
    read,cdummy                                     ;; wait for orders
    IF (cdummy EQ 're-start') THEN BEGIN
        start = 1
        GOTO,restart
    endif

    newfit2:
    index1 = where (xf NE 0.)
    index2 = sort(xf[index1])
    wavcoeff = poly_fit(xf[index2],yf[index2],degree,/double)

;    windowset,1
    plot, xf, yf, psym=5, yrange = [min(yy),max(yy)], ystyle = 1, $
      xtitle='pixel',ytitle='wavelength'
    oplot,xx,yy,color=20
    PRINT,'% SPEX_FIT_WAVE: ready to continue? press return'
    read,cdummy                                     ;; wait for orders
    
;; ---------------------------------------------------------
;; --- POSSIBILITY TO REJECT POINTS FROM FIT (WITHIN AUTOFIND !)
;;
    
;    windowset,2
    yfit = dblarr(countern)
    FOR k = 0,degree DO yfit = yfit + wavcoeff[k]*xf(0:countern-1)^k    
;    plot,xf(0:countern-1),yf(0:countern-1)-yfit,psym=5,ystyle=1,xtitle='pixel'$
;         ,ytitle='residual ';+string("305B)
    plot,xf(0:countern-1),yf(0:countern-1)-yfit,psym=5,ystyle=1,   $
         xtitle='pixel',ytitle='residual '+string("305B),color=20
    plot,xf(0:countern-1),yf(0:countern-1)-yfit,psym=5,ystyle=1,   $
         xtitle='pixel',ytitle='residual '+string("305B),/nodata
    oplot,xf(0:countern-1),yf(0:countern-1)-yfit,color=20

    PRINT,'% SPEX_FIT_WAVE: accepted fit? press return'
    PRINT,'% SPEX_FIT_WAVE: new polynomial fit? enter degree'
    PRINT,'% SPEX_FIT_WAVE: reject points from fit? enter r'
    read,cdummy
    IF cdummy NE '' AND cdummy NE 'r' THEN BEGIN 
        degree = fix(cdummy)
        IF degree GT countern-1 THEN BEGIN 
            PRINT,'% SPEX_FIT_WAVE: not enough points to fit '   + $
              'polynomial of degree '+strtrim(string(degree),2)
            PRINT,'% SPEX_FIT_WAVE: resting to '+strtrim(string(countern-1),2)
            degree = counter-1
        ENDIF 
        GOTO,newfit2
    ENDIF 
    IF cdummy EQ 'r' THEN BEGIN 
           message,'Left   mouse click   : reject points',/inf
           message,'Middle mouse click   : end ',/inf
           message,'Right  mouse click   : reject area ',/inf

           REPEAT BEGIN

               yfit = dblarr(countern)
               FOR k = 0,degree DO yfit = yfit + wavcoeff[k]*xf(0:countern-1)^k    
               plot,xf(0:countern-1),yf(0:countern-1)-yfit,psym=5,ystyle=1,    $
                    xtitle='pixel',ytitle='residual '+string("305B),color=20
               plot,xf(0:countern-1),yf(0:countern-1)-yfit,psym=5,ystyle=1,    $
                    xtitle='pixel',ytitle='residual '+string("305B),/nodata
               oplot,xf(0:countern-1),yf(0:countern-1)-yfit,color=20
               xyouts,xf[0:countern-1],yf(0:countern-1)-yfit,  $
                    strtrim(string(yf(0:countern-1)),2)

               cursor,xx1,yy1,/data
               mouse=!mouse.button
               CASE mouse OF

                   1: BEGIN 
                       diff = (xf(0:countern-1)-xx1)^2 + $
                         (yf(0:countern-1)-yfit-yy1)^2
                       x_reject = where (diff EQ min(diff))
                       ind = where(indgen(countern) NE x_reject(0))
                       countern = n_elements(ind)
                       xf = xf(ind)
                       yf = yf(ind)
                       wait,0.3
                   END

                   2: PRINT,'% SPEX_FIT_WAVE: finished rejection'
                   4: BEGIN
                       message,'next point to mark area ...',/inf
                       wait,0.3
                       cursor,xx2,yy2,/data
                       wait,0.3
                       message,'area marked ...',/inf
                       xx3 = [xx1,xx2]
                       ind1 = sort(xx3)
                       ind  = where (xf(0:countern-1) LT xx3(ind1(0)) OR   $
                                     xf(0:countern-1) GT xx3(ind1(1)))
                       countern = n_elements(ind)
                       xf = xf(ind)
                       yf = yf(ind)
                       wait,0.3
                   END
               ENDCASE 
           ENDREP UNTIL (mouse eq 2)

           GOTO,newfit2                             ;; re-display 
    ENDIF 
    
    ;; --- save selected wavelenghth to select-file
    openw,unit,spectrum+'_select',get_lun
    printf,unit,n_elements(ind)
    FOR ii=0,n_elements(ind)-1 DO printf,unit,yf(ii)
    free_lun,unit


ENDIF

;; ---------------------------------------------------------
;; --- CHECK WAVELENGTh FIT
;;
plot,yy,image,xtitle='wavelength',xstyle=1,xrange=[min(yy),max(yy)]
IF autofind EQ 1 THEN BEGIN
FOR i=0,dim-1 DO BEGIN
    idx = where(yy LT spec(i)+10 AND yy GT spec(i)-10,count)
    IF count GT 0 THEN BEGIN 
        yval = max(image(idx))
        xyouts,spec(i),yval,strtrim(string(spec(i)),2),orientation=90,color=100
    ENDIF 
ENDFOR 
ENDIF
    PRINT,''
    PRINT,'% SPEX_FIT_WAVE: ready to continue ? press return'
    PRINT,''
    read,cdummy

;; ---------------------------------------------------------
;; --- SAVE WAVE COEFFICIENTS TO FILE
;;
 
IF writeFlag EQ 0 THEN BEGIN
    openw,unit,file,/get_lun
    printf,unit,degree
    printf,unit,wavcoeff
    free_lun,unit
ENDIF

;; ---------------------------------------------------------
;; --- END
;;
PRINT,'% SPEX_FIT_WAVE: Done.'

return,wavcoeff
end
